import quixote
from quixote import get_context
import quixote.build.apt as apt
import quixote.fetch.copy as fetch
from quixote.inspection.build import gcc
from quixote.inspection.check import assert_true, assert_equal, expect_true, expect_equal
from quixote.inspection.exec import command


@quixote.builder
def install_gcc():
    apt.update()
    apt.install("gcc")


@quixote.fetcher
def copy_delivery():
    fetch.copy("deliveries/")


@quixote.inspector
def compile_delivery():
    delivery_path = get_context()["delivery_path"]
    gcc(f"{delivery_path}/*.c", output_file="student").check("your delivery cannot be compiled")


@quixote.inspector
def test_with_assertions():
    res = command("./student lalala")
    assert_true(res.return_code == 0, f"invalid exit status: {res.return_code}")
    assert_equal(res.stdout, "lalala\n", f"incorrect output for 'lalala': '{res.stdout}'")


@quixote.inspector
def test_with_requirements():
    res = command("./student lalala")
    expect_true(res.return_code == 0, f"invalid exit status: {res.return_code}")
    expect_equal(res.stdout, "lalala\n", f"incorrect output for 'lalala': '{res.stdout}'")


blueprint = quixote.Blueprint(
    name="validating_an_exercise",
    author="Clément 'Doom' Doumergue"
)
